@@ -16,9 +16,9 @@ class VSGInnerLagModel:
     """
 
     def __init__(self):
-        self.LGId = Lag(u=self.PIvd_y, T=self.Tid, K=-1)  # Id
-        self.LGIq = Lag(u=self.PIvq_y, T=self.Tiq, K=1)   # Iq
-        self.Id0.v_str = '- u * Pref / v'
+        self.LGId = Lag(u=self.PIvd_y, T=self.Tid, K=1)  # Id
+        self.LGIq = Lag(u=self.PIvq_y, T=self.Tiq, K=1)  # Iq
+
         self.Id.e_str = 'LGId_y - Id'
         self.Iq.e_str = 'LGIq_y - Iq'
 
@@ -28,7 +28,15 @@ class REGCV2(REGCV1Data, VSGOuterPIData, VSGInnerLagData,
     """
     Voltage-controlled VSC with VSG control.
 
-    The inner-loop current PI controllers are replaced with lag transfer functions.
+    The inner-loop current PI controllers are replaced with lag transfer
+    functions.
+
+    Notes
+    -----
+    To avoid small-signal stability issues, one take extreme care in setting the
+    PI control gains ``Kpvd``, ``Kivd``, ``Kpvq``, and ``Kivq``, and the emulated
+    inertia ``M`` and damping ``D``.
+
     """
 
     def __init__(self, system, config):
@@ -37,5 +45,5 @@ class REGCV2(REGCV1Data, VSGOuterPIData, VSGInnerLagData,
         VSGInnerLagData.__init__(self)
 
         REGCV1ModelBase.__init__(self, system, config)
-        VSGOuterPIModel.__init__(self)
+        VSGOuterPIModel.__init__(self, vderr='vd-vref2')
         VSGInnerLagModel.__init__(self)
