@@ -25,16 +25,16 @@ class TestDiscrete(unittest.TestCase):
         -------
 
         """
-        self.cmp = Limiter(self.u, self.lower, self.upper)
-        self.cmp.list2array(len(self.u.v))
+        cmp = Limiter(self.u, self.lower, self.upper)
+        cmp.list2array(len(self.u.v))
 
-        self.cmp.check_var()
+        cmp.check_var()
 
-        self.assertSequenceEqual(self.cmp.zl.tolist(),
+        self.assertSequenceEqual(cmp.zl.tolist(),
                                  [1., 1., 1., 1., 0., 0., 0., 0.])
-        self.assertSequenceEqual(self.cmp.zi.tolist(),
+        self.assertSequenceEqual(cmp.zi.tolist(),
                                  [0., 0., 0., 0., 1., 0., 0., 0.])
-        self.assertSequenceEqual(self.cmp.zu.tolist(),
+        self.assertSequenceEqual(cmp.zu.tolist(),
                                  [0., 0., 0., 0., 0., 1., 1., 1.])
 
     def test_sorted_limiter(self):
@@ -45,45 +45,45 @@ class TestDiscrete(unittest.TestCase):
         -------
 
         """
-        self.cmp = Limiter(self.u, self.lower, self.upper)
-        self.cmp.list2array(len(self.u.v))
-        self.cmp.check_var()
+        cmp = Limiter(self.u, self.lower, self.upper)
+        cmp.list2array(len(self.u.v))
+        cmp.check_var()
 
-        self.rcmp = SortedLimiter(self.u, self.lower, self.upper, n_select=1)
-        self.rcmp.list2array(len(self.u.v))
-        self.rcmp.check_var()
+        rcmp = SortedLimiter(self.u, self.lower, self.upper, n_select=1)
+        rcmp.list2array(len(self.u.v))
+        rcmp.check_var()
 
-        self.assertSequenceEqual(self.rcmp.zl.tolist(),
+        self.assertSequenceEqual(rcmp.zl.tolist(),
                                  [0., 0., 1., 0., 0., 0., 0., 0.])
-        self.assertSequenceEqual(self.rcmp.zi.tolist(),
+        self.assertSequenceEqual(rcmp.zi.tolist(),
                                  [1., 1., 0., 1., 1., 1., 1., 0.])
-        self.assertSequenceEqual(self.rcmp.zu.tolist(),
+        self.assertSequenceEqual(rcmp.zu.tolist(),
                                  [0., 0., 0., 0., 0., 0., 0., 1.])
 
         # test when no `n_select` is specified
-        self.rcmp_noselect = SortedLimiter(self.u, self.lower, self.upper)
-        self.rcmp_noselect.list2array(len(self.u.v))
-        self.rcmp_noselect.check_var()
+        rcmp_noselect = SortedLimiter(self.u, self.lower, self.upper)
+        rcmp_noselect.list2array(len(self.u.v))
+        rcmp_noselect.check_var()
 
-        self.assertSequenceEqual(self.rcmp_noselect.zl.tolist(),
-                                 self.cmp.zl.tolist())
-        self.assertSequenceEqual(self.rcmp_noselect.zi.tolist(),
-                                 self.cmp.zi.tolist())
-        self.assertSequenceEqual(self.rcmp_noselect.zu.tolist(),
-                                 self.cmp.zu.tolist())
+        self.assertSequenceEqual(rcmp_noselect.zl.tolist(),
+                                 cmp.zl.tolist())
+        self.assertSequenceEqual(rcmp_noselect.zi.tolist(),
+                                 cmp.zi.tolist())
+        self.assertSequenceEqual(rcmp_noselect.zu.tolist(),
+                                 cmp.zu.tolist())
 
         # test when no `n_select` is over range
-        self.rcmp_noselect = SortedLimiter(self.u, self.lower, self.upper,
+        rcmp_noselect = SortedLimiter(self.u, self.lower, self.upper,
                                            n_select=999)
-        self.rcmp_noselect.list2array(len(self.u.v))
-        self.rcmp_noselect.check_var()
+        rcmp_noselect.list2array(len(self.u.v))
+        rcmp_noselect.check_var()
 
-        self.assertSequenceEqual(self.rcmp_noselect.zl.tolist(),
-                                 self.cmp.zl.tolist())
-        self.assertSequenceEqual(self.rcmp_noselect.zi.tolist(),
-                                 self.cmp.zi.tolist())
-        self.assertSequenceEqual(self.rcmp_noselect.zu.tolist(),
-                                 self.cmp.zu.tolist())
+        self.assertSequenceEqual(rcmp_noselect.zl.tolist(),
+                                 cmp.zl.tolist())
+        self.assertSequenceEqual(rcmp_noselect.zi.tolist(),
+                                 cmp.zi.tolist())
+        self.assertSequenceEqual(rcmp_noselect.zu.tolist(),
+                                 cmp.zu.tolist())
 
     def test_switcher(self):
         p = NumParam()
@@ -160,6 +160,7 @@ class TestDerivative(unittest.TestCase):
     """
     Test `andes.core.discrete.Derivative`
     """
+
     def setUp(self) -> None:
         self.n = 5
         self.data = DummyValue(0)
